==> ktp-contact-runner_0.8.1.orig.tar.bz2: ktp-contact-runner-0.8.1/plasma-runner-ktp-contact.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging
Name[bs]=Brze poruke
Name[ca]=Missatgeria instantània
Name[ca@valencia]=Missatgeria instantània
Name[cs]=Instant Messaging
Name[da]=Instant messaging
Name[de]=Instant-Messaging
Name[el]=Στιγμιαία μηνύματα
Name[es]=Mensajería instantánea
Name[fi]=Pikaviestintä
Name[fr]=Messagerie instantanée
Name[gl]=Mensaxería instantánea
Name[hu]=Azonnali üzenetküldés
Name[ia]=Messageria instantanee
Name[it]=Messaggistica istantanea
Name[kk]=Лезде хабарласу
Name[ko]=인스턴트 메시지
Name[lt]=Tikralaikiai pokalbiai
Name[nb]=Lynmelding
Name[nds]=Kortnarichten
Name[nl]=Instant Messaging
Name[pl]=Komunikator internetowy
Name[pt]=Mensagens Instantâneas
Name[pt_BR]=Mensagens instantâneas
Name[ro]=Mesagerie instantanee
Name[ru]=Система обмена сообщениями
Name[sk]=Priama komunikácia
Name[sl]=Hipno sporočanje
Name[sr]=Брзо гласништво
Name[sr@ijekavian]=Брзо гласништво
Name[sr@ijekavianlatin]=Brzo glasništvo
Name[sr@latin]=Brzo glasništvo
Name[sv]=Direktmeddelanden
Name[tr]=Anında Mesajlaşma
Name[uk]=Миттєвий обмін повідомленнями
Name[x-test]=xxInstant Messagingxx
Name[zh_CN]=即时通讯
Name[zh_TW]=即時訊息
Comment=Start a chat with any of your IM contacts or change your IM status
Comment[bs]=Počnite ćaskanje s nekim od IM kontakta ili promijenite vaš IM status
Comment[ca]=Inicia un xat amb qualsevol dels vostres contactes de MI o canvia el vostre estat de MI
Comment[ca@valencia]=Inicia un xat amb qualsevol dels vostres contactes de MI o canvia el vostre estat de MI
Comment[cs]=Začít rozhovor s kterýmkoliv vaším kontaktem v IM nebo změnit stav na IM
Comment[da]=Start chat med en af dine IM-kontakter eller skift din IM-status
Comment[de]=Chats mit ihren Kontakten starten oder Ihren IM-Status ändern
Comment[el]=Έναρξη συνομιλίας με οποιαδήποτε επαφή στιγμιαίων μηνυμάτων ή αλλαγή της κατάστασής σας
Comment[es]=Iniciar una conversación con cualquiera de sus contactos de MI o cambiar su estado de MI
Comment[fi]=Aloita keskustelu muun pikaviestinkäyttäjän kanssa tai vaihda pikaviestintilaasi
Comment[fr]=Démarre une discussion avec n'importe lequel de vos contacts de messagerie instantanée ou change l'état de celle-ci
Comment[gl]=Inicie unha conversa con calquera dos seus contactos ou cambie seu estado na IM
Comment[hu]=Csevegés indítása az azonnali üzenetküldési partnerei valamelyikével vagy az azonnali üzenetküldési állapotának módosítása
Comment[ia]=Initia conversation con qualcunque de tu contactos de IM o modifica tu status de IM
Comment[it]=Avvia una chat con un tuo contatto di MI oppure cambia il tuo stato di MI
Comment[kk]=Кез-келген лезде хабарласу контактыңызбен чат-әңгімені бастау не күй-жайын өзгерту
Comment[ko]=IM 대화 상대와 대화를 시작하거나 상태 바꾸기
Comment[lt]=Pradėti pokalbį su bet kuriuo TP kontaktu arba pakeiskite savo TP būseną
Comment[nb]=Start en prat med en av dine LM-kontakter eller endre din LM-status
Comment[nds]=En Klöönsnack mit een vun Dien KM-Kontakten starten oder Dien KN-Status ännern
Comment[nl]=Begin een chat met een van uw IM-contactpersonen of wijzig uw IM-status
Comment[pl]=Rozpocznij rozmowę z którymkolwiek z twoich kontaktów lub zmień swoja dostępność
Comment[pt]=Iniciar uma conversa com qualquer um dos seus contactos MI ou mudar o seu estado
Comment[pt_BR]=Inicia um bate-papo com um dos seus contatos de MI ou altera o seu status
Comment[ro]=Începeți o discuție cu oricare dintre contactele de MI sau schimbați-vă starea
Comment[ru]=Начать общение с любым вашим контактом или изменить ваш статус в системе обмена сообщениями
Comment[sk]=Spustiť rozhovor s nejakým z vašich IM kontaktov alebo zmeniť váš IM stav
Comment[sl]=Začnite klepet s katerimkoli izmed vaših stikov hipnega sporočanja ali spremenite vaše stanje
Comment[sr]=Започните ћаскање преко ИМ контакта или измените своје ИМ стање
Comment[sr@ijekavian]=Започните ћаскање преко ИМ контакта или измените своје ИМ стање
Comment[sr@ijekavianlatin]=Započnite ćaskanje preko IM kontakta ili izmenite svoje IM stanje
Comment[sr@latin]=Započnite ćaskanje preko IM kontakta ili izmenite svoje IM stanje
Comment[sv]=Börja chatta med någon direktmeddelandekontakt eller ändra din direktmeddelandestatus
Comment[tr]=IM kişilerinizden biriyle sohbete başlayın veya IM durumunuzu değiştirin
Comment[uk]=Почати спілкування з будь-яким з ваших контактів або змінити ваш запис стану у системах обміну повідомленнями
Comment[x-test]=xxStart a chat with any of your IM contacts or change your IM statusxx
Comment[zh_CN]=与任意您的即时通讯联系人开始聊天或修改您的状态
Comment[zh_TW]=與您的即時訊息聯絡人開始聊天，或是變更您的即時訊息狀態
Icon=user-online

X-KDE-ServiceTypes=Plasma/Runner
Type=Service
X-KDE-Library=krunner_ktp_contacts
X-KDE-PluginInfo-Author=Dan Vratil
X-KDE-PluginInfo-Email=dan@progdan.cz
X-KDE-PluginInfo-Name=ktp_contacts
X-KDE-PluginInfo-Version=@KTP_CONTACT_RUNNER_VERSION@
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-contact-runner-0.8.80.tar.bz2: ktp-contact-runner-0.8.80/plasma-runner-ktp-contact.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging
Name[bs]=Brze poruke
Name[ca]=Missatgeria instantània
Name[ca@valencia]=Missatgeria instantània
Name[cs]=Instant Messaging
Name[da]=Instant messaging
Name[de]=Instant-Messaging
Name[el]=Στιγμιαία μηνύματα
Name[en_GB]=Instant Messaging
Name[es]=Mensajería instantánea
Name[et]=Kiirsuhtlus
Name[fa]=پیام‌رسانی فوری
Name[fi]=Pikaviestintä
Name[fr]=Messagerie instantanée
Name[gl]=Mensaxería instantánea
Name[hu]=Azonnali üzenetküldés
Name[ia]=Messageria instantanee
Name[it]=Messaggistica istantanea
Name[kk]=Лезде хабарласу
Name[ko]=인스턴트 메시지
Name[lt]=Tikralaikiai pokalbiai
Name[nb]=Lynmelding
Name[nds]=Kortnarichten
Name[nl]=Instant Messaging
Name[pl]=Komunikator internetowy
Name[pt]=Mensagens Instantâneas
Name[pt_BR]=Mensagens instantâneas
Name[ro]=Mesagerie instantanee
Name[ru]=Система обмена сообщениями
Name[sk]=Priama komunikácia
Name[sl]=Hipno sporočanje
Name[sr]=Брзо гласништво
Name[sr@ijekavian]=Брзо гласништво
Name[sr@ijekavianlatin]=Brzo glasništvo
Name[sr@latin]=Brzo glasništvo
Name[sv]=Direktmeddelandekontakter
Name[tr]=Anında Mesajlaşma
Name[ug]=مۇڭداشقۇ
Name[uk]=Миттєвий обмін повідомленнями
Name[x-test]=xxInstant Messagingxx
Name[zh_CN]=即时通讯
Name[zh_TW]=即時訊息
Comment=Start a chat with any of your IM contacts or change your IM status
Comment[bs]=Pokrenite ćaskanje s bilo kojim od vaših IM kontakta ili promijenite svoj IM status
Comment[ca]=Inicia un xat amb qualsevol dels vostres contactes de MI o canvia el vostre estat de MI
Comment[ca@valencia]=Inicia un xat amb qualsevol dels vostres contactes de MI o canvia el vostre estat de MI
Comment[cs]=Začít rozhovor s kterýmkoliv vaším kontaktem v IM nebo změnit stav na IM
Comment[da]=Start chat med en af dine IM-kontakter eller skift din IM-status
Comment[de]=Chats mit ihren Kontakten starten oder Ihren IM-Status ändern
Comment[el]=Έναρξη συνομιλίας με οποιαδήποτε επαφή στιγμιαίων μηνυμάτων ή αλλαγή της κατάστασής σας
Comment[en_GB]=Start a chat with any of your IM contacts or change your IM status
Comment[es]=Iniciar una conversación con cualquiera de sus contactos de MI o cambiar su estado de MI
Comment[et]=Vestluse alustamine mõne oma kiirsuhtluskontaktiga või enda kiirsuhtlusoleku muutmine
Comment[fi]=Aloita keskustelu muun pikaviestinkäyttäjän kanssa tai vaihda pikaviestintilaasi
Comment[fr]=Démarre une discussion avec n'importe lequel de vos contacts de messagerie instantanée ou change l'état de celle-ci
Comment[gl]=Inicie unha conversa con calquera dos seus contactos ou cambie seu estado na IM
Comment[hu]=Csevegés indítása az azonnali üzenetküldési partnerei valamelyikével vagy az azonnali üzenetküldési állapotának módosítása
Comment[ia]=Initia conversation con qualcunque de tu contactos de IM o modifica tu status de IM
Comment[it]=Avvia una chat con un tuo contatto di MI oppure cambia il tuo stato di MI
Comment[kk]=Кез-келген лезде хабарласу контактыңызбен чат-әңгімені бастау не күй-жайын өзгерту
Comment[ko]=IM 대화 상대와 대화를 시작하거나 상태 바꾸기
Comment[lt]=Pradėti pokalbį su bet kuriuo TP kontaktu arba pakeiskite savo TP būseną
Comment[nb]=Start en prat med en av dine LM-kontakter eller endre din LM-status
Comment[nds]=En Klöönsnack mit een vun Dien KM-Kontakten starten oder Dien KN-Status ännern
Comment[nl]=Begin een chat met een van uw IM-contactpersonen of wijzig uw IM-status
Comment[pl]=Rozpocznij rozmowę z którymkolwiek z twoich kontaktów lub zmień swoja dostępność
Comment[pt]=Iniciar uma conversa com qualquer um dos seus contactos MI ou mudar o seu estado
Comment[pt_BR]=Inicia um bate-papo com um dos seus contatos de MI ou altera o seu status
Comment[ro]=Începeți o discuție cu oricare dintre contactele de MI sau schimbați-vă starea
Comment[ru]=Начать общение с любым вашим контактом или изменить ваш статус в системе обмена сообщениями
Comment[sk]=Spustiť rozhovor s nejakým z vašich IM kontaktov alebo zmeniť váš IM stav
Comment[sl]=Začnite klepet s katerimkoli izmed vaših stikov hipnega sporočanja ali spremenite vaše stanje
Comment[sr]=Започните ћаскање преко ИМ контакта или измените своје ИМ стање
Comment[sr@ijekavian]=Започните ћаскање преко ИМ контакта или измените своје ИМ стање
Comment[sr@ijekavianlatin]=Započnite ćaskanje preko IM kontakta ili izmenite svoje IM stanje
Comment[sr@latin]=Započnite ćaskanje preko IM kontakta ili izmenite svoje IM stanje
Comment[sv]=Börja chatta med någon direktmeddelandekontakt eller ändra din direktmeddelandestatus
Comment[tr]=IM kişilerinizden biriyle sohbete başlayın veya IM durumunuzu değiştirin
Comment[uk]=Почати спілкування з будь-яким з ваших контактів або змінити ваш запис стану у системах обміну повідомленнями
Comment[x-test]=xxStart a chat with any of your IM contacts or change your IM statusxx
Comment[zh_CN]=与任意您的即时通讯联系人开始聊天或修改您的状态
Comment[zh_TW]=與您的即時訊息聯絡人開始聊天，或是變更您的即時訊息狀態
Icon=user-online

X-KDE-ServiceTypes=Plasma/Runner
Type=Service
X-KDE-Library=krunner_ktp_contacts
X-KDE-PluginInfo-Author=Dan Vratil
X-KDE-PluginInfo-Email=dan@progdan.cz
X-KDE-PluginInfo-Name=ktp_contacts
X-KDE-PluginInfo-Version=@KTP_CONTACT_RUNNER_VERSION@
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
